@@ -51,12 +51,13 @@ class S3Connector(Connector):
         :param target: name of the bucket
         :return: the complete list of all objects
         """
-        response = self.client.list_objects(Bucket=target)
+        response = self.client.list_objects_v2(Bucket=target)
         if 'Contents' in response:
             contents = response['Contents']
 
             while response['IsTruncated']:
-                response = self.client.list_objects(Bucket=target, ContinuationToken=response['NextContinuationToken'])
+                response = self.client.list_objects_v2(Bucket=target,
+                                                       ContinuationToken=response['NextContinuationToken'])
                 contents += response['Contents']
 
             return contents
